summaryrefslogtreecommitdiff
path: root/examples/v3arch/oneliner/manager/cmdgen/getnext-v1-with-custom-mibs-location.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/v3arch/oneliner/manager/cmdgen/getnext-v1-with-custom-mibs-location.py')
-rw-r--r--examples/v3arch/oneliner/manager/cmdgen/getnext-v1-with-custom-mibs-location.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/v3arch/oneliner/manager/cmdgen/getnext-v1-with-custom-mibs-location.py b/examples/v3arch/oneliner/manager/cmdgen/getnext-v1-with-custom-mibs-location.py
index 42e8f46..e693562 100644
--- a/examples/v3arch/oneliner/manager/cmdgen/getnext-v1-with-custom-mibs-location.py
+++ b/examples/v3arch/oneliner/manager/cmdgen/getnext-v1-with-custom-mibs-location.py
@@ -21,7 +21,7 @@
# found relative to $PYTHONPATH. Besides searching MIBs as Python modules
# (which could be egg-ed or not), pysnmp can also search for stand-alone
# files in given directories. The latter could be specified by
# MibVariable.addMibSource() calls. New search path entries are added
# in front of existing ones in search path.
#
from pysnmp.entity.rfc3413.oneliner import cmdgen
@@ -31,8 +31,8 @@ cmdGen = cmdgen.CommandGenerator()
errorIndication, errorStatus, errorIndex, varBindTable = cmdGen.nextCmd(
cmdgen.CommunityData('public', mpModel=0),
cmdgen.UdpTransportTarget(('demo.snmplabs.com', 161)),
- cmdgen.MibVariable('IF-MIB', 'ifDescr').addMibSource('/tmp/mymibs'),
- cmdgen.MibVariable('IF-MIB', 'ifType')
+ cmdgen.ObjectIdentity('IF-MIB', 'ifDescr').addMibSource('/tmp/mymibs'),
+ cmdgen.ObjectIdentity('IF-MIB', 'ifType')
)
if errorIndication:
@@ -21,7 +21,7 @@
# (which could be egg-ed or not), pysnmp can also search for stand-alone
# files in given directories. The latter could be specified by
-# MibVariable.addMibSource() calls. New search path entries are added
+# ObjectIdentity.addMibSource() calls. New search path entries are added
# in front of existing ones in search path.
#